@@ -8,9 +8,10 @@ from ..helpers import import_string_list
 
 class FormatterBase(LogstashFormatterBase):
 
-    def __init__(self, fqdn=False, environment='', event_handlers=[],
-                 *args, **kwargs):
+    def __init__(self, fqdn=False, app_name='', environment='',
+                 event_handlers=[], *args, **kwargs):
         super().__init__(message_type='', fqdn=fqdn, *args, **kwargs)
+        self.app_name = app_name
         self.environment = environment
         self.event_handlers = import_string_list(event_handlers)
 
@@ -31,6 +32,7 @@ class FormatterBase(LogstashFormatterBase):
             'host': self.host,
             'path': record.pathname,
             'environment': self.environment,
+            'app_name': self.app_name,
 
             # Extra Fields
             'level': record.levelname,
@@ -38,7 +40,8 @@ class FormatterBase(LogstashFormatterBase):
         }
 
         # Add extra fields
-        message.update(payload=self.get_extra_fields(record))
+        payload_fields = self.get_extra_fields(record)
+        message.update(payload=payload_fields)
 
         # If exception, add debug info
         if record.exc_info:
